function result = rmsdInterval(A,B, stride)
% result = RMSDInterval(A,B,STRIDE) computes matrix of RMSD values 
% between chains A(i:j) and B(i:j), where the compared sequences
% are advanced by as much as is indicated by the argument STRIDE.
% The sequences should consis of Calphas or backbone atoms.
% The function returns the matrix of RMSD values, but also
% produces a plot itself.

if nargin < 3
    stride = 9;
end
n = floor((size(A.coords,1)-2)/stride);
result = zeros(n,n);
for ii = 1:(n-1)
    for jj = (ii+1):n
        i = (ii-1)*stride + 2;
        j = (jj-1)*stride + 2;
        %[result(ii,jj),rot,trans,modA,modB] = rmsd(A,B,i:j);
        result(ii,jj) = rmsd(A,B,i:j);
        result(jj,ii) = result(ii,jj); %min(abs(norm(A.coords(i,:)-A.coords(j,:))-norm(B.coords(i,:)-B.coords(j,:))), 3.5);
    end
end
fig = figure;
set(fig, 'name', 'RMSD Interval Plot');
surf(result,'EdgeColor','none');
view(0,-90);
colorbar;
xlabel([' stride = ' num2str(stride)]);
